@@ -644,7 +644,9 @@ nsFilePicker::InitNative(nsIWidget *aParent,
 NS_IMETHODIMP
 nsFilePicker::AppendFilter(const nsAString& aTitle, const nsAString& aFilter)
 {
-  mComFilterList.Append(aTitle, aFilter);
+  nsAutoString sanitizedFilter(aFilter);
+  sanitizedFilter.ReplaceChar('%', '_');
+  mComFilterList.Append(aTitle, sanitizedFilter);
   return NS_OK;
 }
 
